@@ -50,7 +50,7 @@ CreateJob::~CreateJob()
 void CreateJob::doStart()
 {
     Q_D(CreateJob);
-    d->tags << d->sessionInternal()->sendCommand("CREATE", '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + '\"');
+    d->sendCommand("CREATE", '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + '\"');
 }
 
 void CreateJob::setMailBox(const QString &mailBox)
