@@ -70,7 +70,6 @@ FetchJob::FetchScope::FetchScope():
 FetchJob::FetchJob(Session *session)
     : Job(*new FetchJobPrivate(this, session, "Fetch"))
 {
-    Q_D(FetchJob);
 }
 
 FetchJob::~FetchJob()
@@ -190,7 +189,7 @@ void FetchJob::doStart()
     }
 
     d->selectedMailBox = d->m_session->selectedMailBox();
-    d->tags << d->sessionInternal()->sendCommand(command, parameters);
+    d->sendCommand(command, parameters);
 }
 
 void FetchJob::handleResponse(const Message &response)
