@@ -122,7 +122,7 @@ void GetMetaDataJob::doStart()
         }
     }
 
-    d->tags << d->sessionInternal()->sendCommand(command, parameters);
+    d->sendCommand(command, parameters);
 //  qCDebug(KIMAP2_LOG) << "SENT: " << command << " " << parameters;
 }
 
