@@ -26,6 +26,12 @@
 
 using namespace KIMAP2;
 
+void JobPrivate::sendCommand(const QByteArray &command, const QByteArray &args)
+{
+    tags << sessionInternal()->sendCommand(command, args);
+    m_currentCommand = command + "" + args;
+}
+
 Job::Job(Session *session)
     : KJob(session), d_ptr(new JobPrivate(session, "Job"))
 {
@@ -61,7 +67,7 @@ void Job::handleResponse(const Message &response)
 void Job::connectionLost()
 {
     Q_D(Job);
-    setError(KJob::UserDefinedError);
+    setError(ConnectionLost);
     setErrorText("Connection to server lost: " + d->m_errorMessage);
     emitResult();
 }
@@ -88,8 +94,8 @@ Job::HandlerResponse Job::handleErrorReplies(const Message &response)
         if (response.content.size() < 2) {
             setErrorText(QString("%1 failed, malformed reply from the server.").arg(d->m_name));
         } else if (response.content[1].toString() != "OK") {
-            setError(UserDefinedError);
-            setErrorText(QString("%1 failed, server replied: %2").arg(d->m_name).arg(QLatin1String(response.toString().constData())));
+            setError(CommandFailed);
+            setErrorText(QString("%1 failed, server replied: %2.\n Sent command: %3").arg(d->m_name).arg(QLatin1String(response.toString().constData())).arg(QString(d->m_currentCommand)));
         }
         d->tags.removeAll(response.content.first().toString());
         if (d->tags.isEmpty()) {   // Only emit result when the last command returned
