@@ -57,7 +57,7 @@ public:
         Authenticate
     };
 
-    LoginJobPrivate(LoginJob *job, Session *session, const QString &name) : JobPrivate(session, name), q(job), encryptionMode(QSsl::UnknownProtocol), startTls(false), authState(Login), plainLoginDisabled(false)
+    LoginJobPrivate(LoginJob *job, Session *session, const QString &name) : JobPrivate(session, name), q(job)
     {
         conn = Q_NULLPTR;
         client_interact = Q_NULLPTR;
@@ -80,12 +80,13 @@ public:
     QString password;
     QString serverGreeting;
 
-    QSsl::SslProtocol encryptionMode;
-    bool startTls;
+    QSsl::SslProtocol encryptionMode = QSsl::UnknownProtocol;
+    bool startTls = false;
     QString authMode;
-    AuthState authState;
+    AuthState authState = Login;
     QStringList capabilities;
-    bool plainLoginDisabled;
+    bool plainLoginDisabled = false;
+    bool connectionIsEncrypted = false;
 
     sasl_conn_t *conn;
     sasl_interact_t *client_interact;
@@ -137,13 +138,13 @@ bool LoginJobPrivate::sasl_interact()
         }
         interact++;
     }
+    //FIXME This should return false at least in some cases
     return true;
 }
 
 LoginJob::LoginJob(Session *session)
     : Job(*new LoginJobPrivate(this, session, QString::fromUtf8("Login")))
 {
-    Q_D(LoginJob);
     qCDebug(KIMAP2_LOG) << this;
 }
 
@@ -257,11 +258,11 @@ void LoginJobPrivate::login()
         //With STARTTLS we have to try to upgrade our connection before the login
         qCInfo(KIMAP2_LOG) << "Starting with tls";
         authState = LoginJobPrivate::StartTls;
-        tags << sessionInternal()->sendCommand("STARTTLS");
+        sendCommand("STARTTLS", {});
         return;
     } else {
-        //If this is unecrypted we can retrieve capabilties. Otherwise we wait for the sslResponse.
-        if (encryptionMode == QSsl::UnknownProtocol) {
+        //If this is supposed to be unecrypted or already encrypted we can retrieve capabilties. Otherwise we wait for the sslResponse.
+        if (encryptionMode == QSsl::UnknownProtocol || connectionIsEncrypted) {
             retrieveCapabilities();
         } else {
             qCInfo(KIMAP2_LOG) << "Waiting for encryption before retrieveing capabilities.";
@@ -273,10 +274,16 @@ void LoginJobPrivate::login()
 void LoginJobPrivate::sslResponse(bool response)
 {
     qCDebug(KIMAP2_LOG) << "Got an ssl response " << response;
+    connectionIsEncrypted = response;
     if (response) {
-        retrieveCapabilities();
+        //It's possible that we receive the ssl info before we receive the server greeting.
+        //In that case we're still in the Disconnected state and shouldn't retrieve the capabilities just yet.
+        //We'll try again via login once the state changes.
+        if (m_session->state() != Session::Disconnected) {
+            retrieveCapabilities();
+        }
     } else {
-        q->setError(LoginJob::UserDefinedError);
+        q->setError(LoginFailed);
         q->setErrorText(QString::fromUtf8("Login failed, TLS negotiation failed."));
         encryptionMode = QSsl::UnknownProtocol;
         q->emitResult();
@@ -287,7 +294,7 @@ void LoginJobPrivate::retrieveCapabilities()
 {
     qCDebug(KIMAP2_LOG) << "Retrieving capabilities.";
     authState = LoginJobPrivate::Capability;
-    tags << sessionInternal()->sendCommand("CAPABILITY");
+    sendCommand("CAPABILITY", {});
 }
 
 void LoginJob::handleResponse(const Message &response)
@@ -348,7 +355,7 @@ void LoginJob::handleResponse(const Message &response)
             sasl_dispose(&d->conn);
         }
 
-        setError(UserDefinedError);
+        setError(LoginFailed);
         setErrorText(QString("%1 failed, server replied: %2").arg(commandName).arg(QLatin1String(response.toString().constData())));
         emitResult();
         return;
@@ -411,7 +418,7 @@ void LoginJob::handleResponse(const Message &response)
             //cleartext login, if enabled
             if (d->authMode.isEmpty()) {
                 if (d->plainLoginDisabled) {
-                    setError(UserDefinedError);
+                    setError(LoginFailed);
                     setErrorText(QString("Login failed, plain login is disabled by the server."));
                     emitResult();
                 } else {
@@ -433,7 +440,7 @@ void LoginJob::handleResponse(const Message &response)
                     }
                 }
                 if (!authModeSupported) {
-                    setError(UserDefinedError);
+                    setError(LoginFailed);
                     setErrorText(QString("Login failed, authentication mode %1 is not supported by the server.").arg(d->authMode));
                     emitResult();
                 } else if (!d->startAuthentication()) {
@@ -464,7 +471,7 @@ bool LoginJobPrivate::startAuthentication()
 {
     //SASL authentication
     if (!initSASL()) {
-        q->setError(LoginJob::UserDefinedError);
+        q->setError(LoginFailed);
         q->setErrorText(QString("Login failed, client cannot initialize the SASL library."));
         return false;
     }
@@ -477,7 +484,7 @@ bool LoginJobPrivate::startAuthentication()
     int result = sasl_client_new("imap", m_session->hostName().toLatin1(), Q_NULLPTR, nullptr, callbacks, 0, &conn);
     if (result != SASL_OK) {
         qCWarning(KIMAP2_LOG) << "sasl_client_new failed with:" << result;
-        q->setError(LoginJob::UserDefinedError);
+        q->setError(LoginFailed);
         q->setErrorText(QString::fromUtf8(sasl_errdetail(conn)));
         return false;
     }
@@ -488,7 +495,8 @@ bool LoginJobPrivate::startAuthentication()
         if (result == SASL_INTERACT) {
             if (!sasl_interact()) {
                 sasl_dispose(&conn);
-                q->setError(LoginJob::UserDefinedError);   //TODO: check up the actual error
+                q->setError(LoginFailed);   //TODO: check up the actual error
+                q->setErrorText(QString("sasl_interact failed"));
                 return false;
             }
         }
@@ -496,7 +504,7 @@ bool LoginJobPrivate::startAuthentication()
 
     if (result != SASL_CONTINUE && result != SASL_OK) {
         qCWarning(KIMAP2_LOG) << "sasl_client_start failed with:" << result;
-        q->setError(LoginJob::UserDefinedError);
+        q->setError(LoginFailed);
         q->setErrorText(QString::fromUtf8(sasl_errdetail(conn)));
         sasl_dispose(&conn);
         return false;
@@ -506,9 +514,9 @@ bool LoginJobPrivate::startAuthentication()
     QByteArray challenge = tmp.toBase64();
 
     if (challenge.isEmpty()) {
-        tags << sessionInternal()->sendCommand("AUTHENTICATE", authMode.toLatin1());
+        sendCommand("AUTHENTICATE", authMode.toLatin1());
     } else {
-        tags << sessionInternal()->sendCommand("AUTHENTICATE", authMode.toLatin1() + ' ' + challenge);
+        sendCommand("AUTHENTICATE", authMode.toLatin1() + ' ' + challenge);
     }
 
     return true;
@@ -518,7 +526,7 @@ void LoginJobPrivate::sendPlainLogin()
 {
     authState = LoginJobPrivate::Login;
     qCDebug(KIMAP2_LOG) << "sending LOGIN";
-    tags << sessionInternal()->sendCommand("LOGIN",
+    sendCommand("LOGIN",
             '"' + quoteIMAP(userName).toUtf8() + '"' +
             ' ' +
             '"' + quoteIMAP(password).toUtf8() + '"');
@@ -538,7 +546,8 @@ bool LoginJobPrivate::answerChallenge(const QByteArray &data)
 
         if (result == SASL_INTERACT) {
             if (!sasl_interact()) {
-                q->setError(LoginJob::UserDefinedError);   //TODO: check up the actual error
+                q->setError(LoginFailed);   //TODO: check up the actual error
+                q->setErrorText(QString("sasl_interact failed"));
                 sasl_dispose(&conn);
                 return false;
             }
@@ -547,7 +556,7 @@ bool LoginJobPrivate::answerChallenge(const QByteArray &data)
 
     if (result != SASL_CONTINUE && result != SASL_OK) {
         qCWarning(KIMAP2_LOG) << "sasl_client_step failed with:" << result;
-        q->setError(LoginJob::UserDefinedError);   //TODO: check up the actual error
+        q->setError(LoginFailed);   //TODO: check up the actual error
         q->setErrorText(QString::fromUtf8(sasl_errdetail(conn)));
         sasl_dispose(&conn);
         return false;
@@ -605,15 +614,15 @@ void LoginJob::connectionLost()
 
     qCWarning(KIMAP2_LOG) << "Connection to server lost " << d->m_socketError;
     if (d->m_socketError == QSslSocket::SslHandshakeFailedError) {
-        setError(ERR_SSL_HANDSHAKE_FAILED);
+        setError(SslHandshakeFailed);
         setErrorText(QString::fromUtf8("SSL handshake failed."));
         emitResult();
     } else if (d->m_socketError == QSslSocket::HostNotFoundError) {
-        setError(ERR_HOST_NOT_FOUND);
+        setError(HostNotFound);
         setErrorText(QString::fromUtf8("Host not found."));
         emitResult();
     } else {
-        setError(ERR_COULD_NOT_CONNECT);
+        setError(CouldNotConnect);
         setErrorText(QString::fromUtf8("Connection to server lost."));
         emitResult();
     }
