@@ -403,7 +403,7 @@ void SearchJob::doStart()
         command = "UID " + command;
     }
 
-    d->tags << d->sessionInternal()->sendCommand(command, searchKey);
+    d->sendCommand(command, searchKey);
 }
 
 void SearchJob::handleResponse(const Message &response)
