@@ -24,7 +24,7 @@
 #include "session.h"
 #include "session_p.h"
 
-#include <QtCore/QDebug>
+#include <QDebug>
 
 #include "kimap_debug.h"
 
@@ -544,7 +544,7 @@ void SessionPrivate::onSocketTimeout()
     }
     if (currentJob) {
         qCWarning(KIMAP2_LOG) << "Current job: " << currentJob->metaObject()->className();
-        currentJob->setErrorMessage("Aborting on socket timeout. Interval" + QString::number(socketTimerInterval));
+        currentJob->setErrorMessage("Aborting on socket timeout. Interval " + QString::number(socketTimerInterval) + " ms");
     }
     socket->abort();
     socketProgressTimer.stop();
@@ -572,11 +572,10 @@ QString SessionPrivate::getStateName() const
 void SessionPrivate::onSocketProgressTimeout()
 {
     if (currentJob) {
-        qCDebug(KIMAP2_LOG) << "Processing job: " << currentJob->metaObject()->className();
+        qCDebug(KIMAP2_LOG) << "Processing job: " << currentJob->metaObject()->className() << "Current state: " << getStateName() << (socket ? socket->state() : QAbstractSocket::UnconnectedState);
     } else {
-        qCDebug(KIMAP2_LOG) << "Next job: " << (queue.isEmpty() ? "No job" : queue.head()->metaObject()->className());
+        qCDebug(KIMAP2_LOG) << "Next job: " << (queue.isEmpty() ? "No job" : queue.head()->metaObject()->className()) << "Current state: " << getStateName() << (socket ? socket->state() : QAbstractSocket::UnconnectedState);
     }
-    qCDebug(KIMAP2_LOG) << "Current state: " << getStateName();
 }
 
 void SessionPrivate::writeDataQueue()
