@@ -164,7 +164,7 @@ void StoreJob::doStart()
 
     QByteArray parameters = d->set.toImapSequenceSet() + ' ';
 
-    if (!d->flags.isEmpty()) {
+    if (!d->flags.isEmpty() || d->mode == SetFlags) {
         parameters += d->addFlags("FLAGS", d->flags);
     }
     if (!d->gmLabels.isEmpty()) {
@@ -181,7 +181,7 @@ void StoreJob::doStart()
         command = "UID " + command;
     }
 
-    d->tags << d->sessionInternal()->sendCommand(command, parameters);
+    d->sendCommand(command, parameters);
 }
 
 void StoreJob::handleResponse(const Message &response)
